<?PHP
/**
 * Constains lists for grouping languages.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing spelled out languages.
 */
final class MDConcLanguages implements MDImporterConcordanceListInterface {

    private const LANGUAGES_LIST = [
        # English
        'English' => 'en',
        'eng' => 'en',
        'EN' => 'en',
        'ENG' => 'en',

        # German
        'Deutsch' => 'de',
        'German' => 'de',
        'deu' => 'de',

        # Hungarian
        'Hungarian' => 'hu',
        'Magyar' => 'hu',
    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (!isset(self::LANGUAGES_LIST[$input])) {
            throw new MDImporterMissingConcordance("Unknown language type: " . $input);
        }

        return self::LANGUAGES_LIST[$input];

    }
}
